==> org-lsst-ccs-subsystem-fcs-gui-7.1.0-sources.jar: org/lsst/ccs/subsystems/fcs/ui/commons/AcceleroPanel.java <==

package org.lsst.ccs.subsystems.fcs.ui.commons;

import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.text.DecimalFormat;
import java.util.logging.Logger;
import javax.swing.BorderFactory;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.SwingUtilities;
import javax.swing.table.DefaultTableModel;
import javax.swing.table.TableColumn;
import org.lsst.ccs.subsystems.fcs.StatusDataPublishedByAccelerometer;
import static org.lsst.ccs.subsystems.fcs.ui.commons.Tools.insets_std;
import static org.lsst.ccs.subsystems.fcs.ui.commons.Tools.NICE_PINK;
import static org.lsst.ccs.subsystems.fcs.ui.commons.Tools.resetTable;

/**
 * A panel to display values published by accelerometer.
 * See CanOpenMG550P.java
 *
 * @author virieux
 */
public class AcceleroPanel extends JPanel {
    private static final Logger FCSLOG = Logger.getLogger(AcceleroPanel.class.getName());

    private JTable accelTable;
    private JScrollPane jScrollPane;

    private final DecimalFormat formatter = new DecimalFormat("#####0.00");

    private JTable airmassTable;
    private JScrollPane jScrollPane2;

    /**
     * Creates a new AcceleroPanel and initialize all its components.
     */
    public AcceleroPanel() {
        initComponents();
    }

    private class UpdateAccelero implements Runnable {

        private StatusDataPublishedByAccelerometer s;

        public UpdateAccelero(StatusDataPublishedByAccelerometer status) {
            this.s = status;
        }

        @Override
        public void run() {
            DefaultTableModel filterTableModel = (DefaultTableModel) accelTable.getModel();
            accelTable.setValueAt(formatter.format(s.getAngularVelocityX()), 0, 1);
            accelTable.setValueAt(formatter.format(s.getAngularVelocityY()), 0, 2);
            accelTable.setValueAt(formatter.format(s.getAngularVelocityZ()), 0, 3);
            accelTable.setValueAt(formatter.format(s.getAccelerationX()), 1, 1);
            accelTable.setValueAt(formatter.format(s.getAccelerationY()), 1, 2);
            accelTable.setValueAt(formatter.format(s.getAccelerationZ()), 1, 3);
            filterTableModel.fireTableDataChanged();

            DefaultTableModel airmassTableModel = (DefaultTableModel) airmassTable.getModel();
            FCSLOG.finer(() -> "accelero  gravity = " + s.getGravity());
            FCSLOG.finer(() -> "accelero elevation = " + s.getElevation());
            FCSLOG.finer(() -> "accelero azimut = " + s.getAzimut());
            FCSLOG.finer(() -> "accelero airmass = " + s.getAirmass());
            airmassTable.setValueAt(formatter.format(s.getGravity()), 0, 0);
            airmassTable.setValueAt(formatter.format(s.getElevation()), 0, 1);
            airmassTable.setValueAt(formatter.format(s.getAzimut()), 0, 2);
            airmassTable.setValueAt(formatter.format(s.getAirmass()), 0, 3);
            airmassTableModel.fireTableDataChanged();
        }
    }

    public void updateAccelero(StatusDataPublishedByAccelerometer s) {
        SwingUtilities.invokeLater(new UpdateAccelero(s));
    }

    @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Form description">
    private void initComponents() {

        /**
         ******************************************************************************
         ** Accelero Table
         * *****************************************************************************
         */
        jScrollPane = new JScrollPane();
        accelTable = new JTable();
        accelTable.setModel(new DefaultTableModel(
                new Object[][]{},
                new String[]{
                    "", "X AXE", "Y AXE", "Z AXE"
                }
        ) {
            private static final long serialVersionUID = -6158042587124966771L;
            private final Class[] types = new Class[]{
                String.class, Integer.class, Integer.class, Integer.class
            };
            private final boolean[] canEdit = new boolean[]{
                false, false, false, false};

            @Override
            public Class getColumnClass(int columnIndex) {
                return types[columnIndex];
            }

            @Override
            public boolean isCellEditable(int rowIndex, int columnIndex) {
                return canEdit[columnIndex];
            }
        });
        accelTable.setName("accelTable");
        /* table initialization */
        setDefaultAcceleroValues();

        /* column size*/
        TableColumn column;
        int rowNB = accelTable.getModel().getRowCount();
        for (int i = 0; i < rowNB; i++) {
            column = accelTable.getColumnModel().getColumn(i);
            if (i == 0) {
                column.setPreferredWidth(150); //first column is bigger
            }
        }
        jScrollPane.setPreferredSize(new java.awt.Dimension(500, 60));
        jScrollPane.setViewportView(accelTable);

        /**
         ******************************************************************************
         ** end of Accelero Table
         * *****************************************************************************
         */
        initAirmassTable();

        //Whole Panel
        setBorder(BorderFactory.createTitledBorder(BorderFactory.createLineBorder(NICE_PINK),"Back Flange Accelerometer"));
        setLayout(new GridBagLayout());
        GridBagConstraints gbc = new GridBagConstraints();

        gbc.anchor = java.awt.GridBagConstraints.BASELINE_LEADING;
        gbc.insets = insets_std;
        gbc.gridx = 0;
        gbc.gridy = 0;
        add(jScrollPane, gbc);
        gbc.gridy++;
        add(jScrollPane2, gbc);
    }

    public void initAirmassTable() {
        /**
         ******************************************************************************
         ** Airmass Table
         * *****************************************************************************
         */
        jScrollPane2 = new JScrollPane();
        airmassTable = new JTable();
        airmassTable.setModel(new DefaultTableModel(
                new Object[][]{},
                new String[]{
                    "Gravity", "Elevation", "Azimut", "Airmass"
                }
        ) {
//            private static final long serialVersionUID = -6158042587124966771L;
            private final Class[] types = new Class[]{
                Integer.class, Integer.class, Integer.class, Integer.class
            };
            private final boolean[] canEdit = new boolean[]{
                false, false, false, false};

            @Override
            public Class getColumnClass(int columnIndex) {
                return types[columnIndex];
            }

            @Override
            public boolean isCellEditable(int rowIndex, int columnIndex) {
                return canEdit[columnIndex];
            }
        });
        airmassTable.setName("airmassTable");
        /* table initialization */
        setDefaultAirmassValues();

        /* column size*/
        TableColumn column;
        int rowNB = airmassTable.getModel().getRowCount();
        for (int i = 0; i < rowNB; i++) {
            column = airmassTable.getColumnModel().getColumn(i);
            if (i == 0) {
                column.setPreferredWidth(150); //first column is bigger
            }
        }
        jScrollPane2.setPreferredSize(new java.awt.Dimension(500, 60));
        jScrollPane2.setViewportView(airmassTable);

        /**
         ******************************************************************************
         ** end of Airmass Table
         * *****************************************************************************
         */
    }

    /**
     * Fill up the airmass table with default values.
     */
    private void setDefaultAirmassValues() {
        DefaultTableModel airmassTableModel = (DefaultTableModel) airmassTable.getModel();
        Object[] row1 = {0, 0, 0, 0};
        airmassTableModel.addRow(row1);
        airmassTableModel.fireTableDataChanged();
    }

    /**
     * Fill up the accelerometer table with default values.
     */
    private void setDefaultAcceleroValues() {
        DefaultTableModel accelTableModel = (DefaultTableModel) accelTable.getModel();
        Object[] row1 = {"ANGULAR VELOCITY", 0, 0, 0};
        accelTableModel.addRow(row1);
        Object[] row2 = {"ACCELERATION (g0)", 0, 0, 0};
        accelTableModel.addRow(row2);
        accelTableModel.fireTableDataChanged();
    }

    /**
     * Remove data on panel.
     * To be used when subsystem is disconnecting.
     */
    public void resetPanel() {
        resetTable(accelTable);
        setDefaultAcceleroValues();
        resetTable(airmassTable);
        setDefaultAirmassValues();
    }

    /**
     * Just for tests.
     *
     * @param argv
     */
    public static void main(String[] argv) {

        AcceleroPanel p = new AcceleroPanel();

        JFrame frame = new JFrame("Accelero Values");
        frame.setContentPane(p);
        frame.pack();
        frame.setVisible(true);
        frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);

    }
}

==> org-lsst-ccs-subsystem-fcs-gui-8.2.0-20250509.224338-1-sources.jar: org/lsst/ccs/subsystems/fcs/ui/commons/AcceleroPanel.java <==

package org.lsst.ccs.subsystems.fcs.ui.commons;

import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.text.DecimalFormat;
import java.util.logging.Logger;
import javax.swing.BorderFactory;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.SwingUtilities;
import javax.swing.table.DefaultTableModel;
import javax.swing.table.TableColumn;
import org.lsst.ccs.subsystems.fcs.StatusDataPublishedByAccelerometer;
import static org.lsst.ccs.subsystems.fcs.ui.commons.Tools.insets_std;
import static org.lsst.ccs.subsystems.fcs.ui.commons.Tools.NICE_PINK;
import static org.lsst.ccs.subsystems.fcs.ui.commons.Tools.resetTable;

/**
 * A panel to display values published by accelerometer.
 * See CanOpenMG550P.java
 *
 * @author virieux
 */
public class AcceleroPanel extends JPanel {
    private static final Logger FCSLOG = Logger.getLogger(AcceleroPanel.class.getName());

    private JTable accelTable;
    private JScrollPane jScrollPane;

    private final DecimalFormat formatter = new DecimalFormat("#####0.00");

    private JTable airmassTable;
    private JScrollPane jScrollPane2;

    /**
     * Creates a new AcceleroPanel and initialize all its components.
     */
    public AcceleroPanel() {
        initComponents();
    }

    private class UpdateAccelero implements Runnable {

        private StatusDataPublishedByAccelerometer s;

        public UpdateAccelero(StatusDataPublishedByAccelerometer status) {
            this.s = status;
        }

        @Override
        public void run() {
            DefaultTableModel filterTableModel = (DefaultTableModel) accelTable.getModel();
            accelTable.setValueAt(formatter.format(s.getAngularVelocityX()), 0, 1);
            accelTable.setValueAt(formatter.format(s.getAngularVelocityY()), 0, 2);
            accelTable.setValueAt(formatter.format(s.getAngularVelocityZ()), 0, 3);
            accelTable.setValueAt(formatter.format(s.getAccelerationX()), 1, 1);
            accelTable.setValueAt(formatter.format(s.getAccelerationY()), 1, 2);
            accelTable.setValueAt(formatter.format(s.getAccelerationZ()), 1, 3);
            filterTableModel.fireTableDataChanged();

            DefaultTableModel airmassTableModel = (DefaultTableModel) airmassTable.getModel();
            FCSLOG.finer(() -> "accelero  gravity = " + s.getGravity());
            FCSLOG.finer(() -> "accelero elevation = " + s.getElevation());
            FCSLOG.finer(() -> "accelero azimut = " + s.getAzimut());
            FCSLOG.finer(() -> "accelero airmass = " + s.getAirmass());
            airmassTable.setValueAt(formatter.format(s.getGravity()), 0, 0);
            airmassTable.setValueAt(formatter.format(s.getElevation()), 0, 1);
            airmassTable.setValueAt(formatter.format(s.getAzimut()), 0, 2);
            airmassTable.setValueAt(formatter.format(s.getAirmass()), 0, 3);
            airmassTableModel.fireTableDataChanged();
        }
    }

    public void updateAccelero(StatusDataPublishedByAccelerometer s) {
        SwingUtilities.invokeLater(new UpdateAccelero(s));
    }

    private void initComponents() {

        /**
         ******************************************************************************
         ** Accelero Table
         * *****************************************************************************
         */
        jScrollPane = new JScrollPane();
        accelTable = new JTable();
        accelTable.setModel(new DefaultTableModel(
                new Object[][]{},
                new String[]{
                    "", "X AXE", "Y AXE", "Z AXE"
                }
        ) {
            private static final long serialVersionUID = -6158042587124966771L;
            private final Class<?>[] types = new Class[]{
                String.class, Integer.class, Integer.class, Integer.class
            };
            private final boolean[] canEdit = new boolean[]{
                false, false, false, false};

            @Override
            public Class<?> getColumnClass(int columnIndex) {
                return types[columnIndex];
            }

            @Override
            public boolean isCellEditable(int rowIndex, int columnIndex) {
                return canEdit[columnIndex];
            }
        });
        accelTable.setName("accelTable");
        /* table initialization */
        setDefaultAcceleroValues();

        /* column size*/
        TableColumn column;
        int rowNB = accelTable.getModel().getRowCount();
        for (int i = 0; i < rowNB; i++) {
            column = accelTable.getColumnModel().getColumn(i);
            if (i == 0) {
                column.setPreferredWidth(150); //first column is bigger
            }
        }
        jScrollPane.setPreferredSize(new java.awt.Dimension(500, 60));
        jScrollPane.setViewportView(accelTable);

        /**
         ******************************************************************************
         ** end of Accelero Table
         * *****************************************************************************
         */
        initAirmassTable();

        //Whole Panel
        setBorder(BorderFactory.createTitledBorder(BorderFactory.createLineBorder(NICE_PINK),"Back Flange Accelerometer"));
        setLayout(new GridBagLayout());
        GridBagConstraints gbc = new GridBagConstraints();

        gbc.anchor = java.awt.GridBagConstraints.BASELINE_LEADING;
        gbc.insets = insets_std;
        gbc.gridx = 0;
        gbc.gridy = 0;
        add(jScrollPane, gbc);
        gbc.gridy++;
        add(jScrollPane2, gbc);
    }

    public void initAirmassTable() {
        /**
         ******************************************************************************
         ** Airmass Table
         * *****************************************************************************
         */
        jScrollPane2 = new JScrollPane();
        airmassTable = new JTable();
        airmassTable.setModel(new DefaultTableModel(
                new Object[][]{},
                new String[]{
                    "Gravity", "Elevation", "Azimut", "Airmass"
                }
        ) {
//            private static final long serialVersionUID = -6158042587124966771L;
            private final Class<?>[] types = new Class[]{
                Integer.class, Integer.class, Integer.class, Integer.class
            };
            private final boolean[] canEdit = new boolean[]{
                false, false, false, false};

            @Override
            public Class<?> getColumnClass(int columnIndex) {
                return types[columnIndex];
            }

            @Override
            public boolean isCellEditable(int rowIndex, int columnIndex) {
                return canEdit[columnIndex];
            }
        });
        airmassTable.setName("airmassTable");
        /* table initialization */
        setDefaultAirmassValues();

        /* column size*/
        TableColumn column;
        int rowNB = airmassTable.getModel().getRowCount();
        for (int i = 0; i < rowNB; i++) {
            column = airmassTable.getColumnModel().getColumn(i);
            if (i == 0) {
                column.setPreferredWidth(150); //first column is bigger
            }
        }
        jScrollPane2.setPreferredSize(new java.awt.Dimension(500, 60));
        jScrollPane2.setViewportView(airmassTable);

        /**
         ******************************************************************************
         ** end of Airmass Table
         * *****************************************************************************
         */
    }

    /**
     * Fill up the airmass table with default values.
     */
    private void setDefaultAirmassValues() {
        DefaultTableModel airmassTableModel = (DefaultTableModel) airmassTable.getModel();
        Object[] row1 = {0, 0, 0, 0};
        airmassTableModel.addRow(row1);
        airmassTableModel.fireTableDataChanged();
    }

    /**
     * Fill up the accelerometer table with default values.
     */
    private void setDefaultAcceleroValues() {
        DefaultTableModel accelTableModel = (DefaultTableModel) accelTable.getModel();
        Object[] row1 = {"ANGULAR VELOCITY", 0, 0, 0};
        accelTableModel.addRow(row1);
        Object[] row2 = {"ACCELERATION (g0)", 0, 0, 0};
        accelTableModel.addRow(row2);
        accelTableModel.fireTableDataChanged();
    }

    /**
     * Remove data on panel.
     * To be used when subsystem is disconnecting.
     */
    public void resetPanel() {
        resetTable(accelTable);
        setDefaultAcceleroValues();
        resetTable(airmassTable);
        setDefaultAirmassValues();
    }

    /**
     * Just for tests.
     *
     * @param argv
     */
    public static void main(String[] argv) {

        AcceleroPanel p = new AcceleroPanel();

        JFrame frame = new JFrame("Accelero Values");
        frame.setContentPane(p);
        frame.pack();
        frame.setVisible(true);
        frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);

    }
}
